[Pkg-mozext-commits] [tabmixplus] 65/73: Fix all typos after Webstorm spellcheck - chrome

David Prévot taffit at moszumanska.debian.org
Mon May 9 02:30:57 UTC 2016


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository tabmixplus.

commit 83c189349e2c7ec9e4c2c27ab59626b0c6c3b3cc
Author: onemen <tabmix.onemen at gmail.com>
Date:   Sun Apr 24 17:38:01 2016 +0300

    Fix all typos after Webstorm spellcheck - chrome
---
 chrome/content/changecode.js                     |   2 +-
 chrome/content/click/click.js                    |   4 +-
 chrome/content/extensions/extensions.js          |  12 +--
 chrome/content/flst/lasttab.js                   |  10 +-
 chrome/content/links/setup.js                    |   8 +-
 chrome/content/links/userInterface.js            |   6 +-
 chrome/content/minit/minit.js                    |  26 ++---
 chrome/content/minit/tabView.js                  |  14 +--
 chrome/content/minit/tablib.js                   |  42 ++++----
 chrome/content/overlay/browser.css               |   2 +-
 chrome/content/overlay/firefox.css               |   2 +-
 chrome/content/places/places.js                  |  20 ++--
 chrome/content/session/promptservice.js          |   2 +-
 chrome/content/session/promptservice.xul         |   2 +-
 chrome/content/session/session.js                | 124 +++++++++++------------
 chrome/content/session/sessionStore.js           |  16 +--
 chrome/content/tab/scrollbox.xml                 |   2 +-
 chrome/content/tab/tab.js                        |  78 +++++++-------
 chrome/content/tabmix.js                         |  38 +++----
 chrome/content/tabmix.xul                        |   2 +-
 chrome/content/utils.js                          |   6 +-
 chrome/locale/en-US/pref-tabmix.dtd              |   2 +-
 chrome/skin/app_version/39.0/tabStyles.css       |   6 +-
 chrome/skin/app_version/39.0/win/tabStyles.css   |   2 +-
 chrome/skin/app_version/all/linux/browser.css    |   2 +-
 chrome/skin/app_version/before39.0/tabStyles.css |   6 +-
 chrome/skin/preferences.css                      |  12 +--
 chrome/skin/renameTab.css                        |   2 +-
 defaults/preferences/tabmix.js                   |   5 +-
 modules/TabGroupsMigrator.jsm                    |   2 +-
 modules/extensions/TabGroupsManager.jsm          |   2 +-
 31 files changed, 230 insertions(+), 229 deletions(-)

diff --git a/chrome/content/changecode.js b/chrome/content/changecode.js
index bda76e8..20a54a7 100644
--- a/chrome/content/changecode.js
+++ b/chrome/content/changecode.js
@@ -1,7 +1,7 @@
 /* eslint strict: 0 */
 
 // don't use strict for this file
-// so we don't evaluat all code as strict mode code
+// so we don't evaluate all code as strict mode code
 
 // aOptions can be: getter, setter or forceUpdate
 Tabmix.changeCode = function(aParent, afnName, aOptions) {
diff --git a/chrome/content/click/click.js b/chrome/content/click/click.js
index 86e37d1..22d2f57 100644
--- a/chrome/content/click/click.js
+++ b/chrome/content/click/click.js
@@ -334,7 +334,7 @@ var TabmixContext = {
       }
     }
 
-    // insret IE Tab menu-items before Bookmakrs menu-items
+    // insert IE Tab menu-items before Bookmarks menu-items
     if ("gIeTab" in window) { // no need to do this fix for IE Tab 2
       var aFunction = "createTabbarMenu" in IeTab.prototype ? "createTabbarMenu" : "init";
       if (aFunction in IeTab.prototype) {
@@ -622,7 +622,7 @@ var TabmixContext = {
      /**
       * from Firefox 4.0 2009-09-11 there is gContextMenu.openLinkInCurrent
       * Firefox only show this menu when the selection text is url see Bug 454518
-      * we cahck if gContextMenu.linkURL contain URL
+      * we check if gContextMenu.linkURL contain URL
       */
       var onLink = gContextMenu.onLink || gContextMenu.linkURL;
       Tabmix.showItem("context-openlinkincurrent", Tabmix.prefs.getBoolPref("openLinkHere") && onLink);
diff --git a/chrome/content/extensions/extensions.js b/chrome/content/extensions/extensions.js
index bc2d862..aea1fd2 100644
--- a/chrome/content/extensions/extensions.js
+++ b/chrome/content/extensions/extensions.js
@@ -252,7 +252,7 @@ var TMP_extensionsCompatibility = {
     }
 
     // Firefox sync
-    // fix bug in firefox sync that add new menu itep from each popupshowing
+    // fix bug in firefox sync that add new menu item from each popupshowing
     if ("gFxWeaveGlue" in window) {
       Tabmix.changeCode(gFxWeaveGlue, "gFxWeaveGlue.handleEvent")._replace(
         'else if (this.getPageIndex() == -1)',
@@ -330,10 +330,10 @@ var TMP_extensionsCompatibility = {
       ).toCode();
     }
 
-    // for MR Tech's local install extention
+    // for MR Tech's local install extension
     if (typeof (Local_Install) == "object") {
-      // don't open trober in current tab when tab is locked
-      // or trober is to diffrent site then the current
+      // don't open 'Throbber' in current tab when tab is locked
+      // or 'Throbber' is to different site then the current
       Tabmix.changeCode(Local_Install, "Local_Install.openThrobber")._replace(
         'local_common.openURL(local_common.getThrobberURL(), inNewTab);',
         'var url = local_common.getThrobberURL(); \
@@ -349,7 +349,7 @@ var TMP_extensionsCompatibility = {
     }
 
     if ("FireGestures" in window) {
-      // unable to close surce tab after duplicate with FireGestures esextension
+      // unable to close source tab after duplicate with FireGestures extension
       // problem fix in FireGestures 1.5.7 keep this here for users with older versions
       let performAction = FireGestures._performAction.toString();
       let codeToReplace = "gBrowser.moveTabTo(newTab, ++orgTab._tPos);";
@@ -724,7 +724,7 @@ TMP_extensionsCompatibility.treeStyleTab = {
        *  we replace TMP_Bookmark.openGroup with TMP_Places.openGroup at Tabmix 0.3.8.2pre.090830
        *  we also replace call to TreeStyleTabService.openGroupBookmarkBehavior();
        *  with aOpenGroupBookmarkBehavior that we pass from PlacesUIUtils._openTabset
-       *  we only call this functiom from browserWindow so we don't need to call it for
+       *  we only call this function from browserWindow so we don't need to call it for
        *  other places windows
        */
       Tabmix.changeCode(TMP_Places, "TMP_Places.openGroup")._replace(
diff --git a/chrome/content/flst/lasttab.js b/chrome/content/flst/lasttab.js
index f0e90f4..fd4f682 100644
--- a/chrome/content/flst/lasttab.js
+++ b/chrome/content/flst/lasttab.js
@@ -30,11 +30,11 @@ var TMP_LastTab = {
 
     // show the list at the center of the screen
     let box = tablist.boxObject;
-    let letf = () => screen.availLeft + (screen.availWidth - box.width) / 2;
+    let left = () => screen.availLeft + (screen.availWidth - box.width) / 2;
     let top = () => screen.availTop + (screen.availHeight - box.height) / 2;
     tablist.style.visibility = "hidden";
-    tablist.openPopupAtScreen(letf(), top(), true);
-    tablist.moveTo(letf(), top());
+    tablist.openPopupAtScreen(left(), top(), true);
+    tablist.moveTo(left(), top());
     tablist.style.visibility = "";
 
     var ietab = "chrome://ietab/content/reloaded.html?url=";
@@ -374,9 +374,9 @@ var TMP_LastTab = {
     var mostRecentlyUsed = Services.prefs.getBoolPref("browser.ctrlTab.previews");
     var tabPreviews = document.getElementById("ctrlTab-panel") && "ctrlTab" in window;
     if (tabPreviews) {
-      var tabPreviewsCurentStatus = Boolean(ctrlTab._recentlyUsedTabs);
+      var tabPreviewsCurrentStatus = Boolean(ctrlTab._recentlyUsedTabs);
       tabPreviews = mostRecentlyUsed && Tabmix.prefs.getBoolPref("lasttab.tabPreviews");
-      if (tabPreviewsCurentStatus != tabPreviews) {
+      if (tabPreviewsCurrentStatus != tabPreviews) {
         if (tabPreviews) {
           ctrlTab.init();
           ctrlTab._recentlyUsedTabs = [];
diff --git a/chrome/content/links/setup.js b/chrome/content/links/setup.js
index 336a7de..d871a77 100644
--- a/chrome/content/links/setup.js
+++ b/chrome/content/links/setup.js
@@ -4,7 +4,7 @@
  * chrome://tabmixplus/content/links/setup.js
  *
  * original code by Bradley Chapman
- * modified and developped by Hemiola SUN
+ * modified and developed by Hemiola SUN
  * modified again by Bradley Chapman
  *
  */
@@ -211,8 +211,8 @@ Tabmix.beforeStartup = function TMP_beforeStartup(tabBrowser, aTabContainer) {
 
   /**
    * add gBrowser.getTabForBrowser if it is not exist
-   * gBrowser.getTabForBrowser exsit since Firefox 35 (Bug 1039500)
-   * gBrowser._getTabForBrowser exsit since Firefox 23 (Bug 662008)
+   * gBrowser.getTabForBrowser exist since Firefox 35 (Bug 1039500)
+   * gBrowser._getTabForBrowser exist since Firefox 23 (Bug 662008)
    */
   if (typeof tabBrowser.getTabForBrowser != "function") {
     // this is _getTabForBrowser version from Firefox 23
@@ -325,7 +325,7 @@ Tabmix.adjustTabstrip = function tabContainer_adjustTabstrip(skipUpdateScrollSta
 
  /**
   *  Don't use return in this function
-  *  TreeStyleTabe add some code at the end
+  *  TreeStyleTab add some code at the end
   */
   let transitionend = Tabmix.callerTrace("onxbltransitionend");
   if (tabsCount == 1) {
diff --git a/chrome/content/links/userInterface.js b/chrome/content/links/userInterface.js
index bae5c1c..4c90fa2 100644
--- a/chrome/content/links/userInterface.js
+++ b/chrome/content/links/userInterface.js
@@ -5,7 +5,7 @@
  * chrome://tabmixplus/content/links/userInterface.js
  *
  * original code by Bradley Chapman
- * modified and developped by Hemiola SUN
+ * modified and developed by Hemiola SUN
  * modified again by Bradley Chapman
  *
  * modified again and again... by onemen
@@ -208,7 +208,7 @@ Tabmix.clearUrlBar = function TMP_clearUrlBar(aTab, aUrl, aTimeOut, replaceLastT
   if (!replaceLastTab && /about:home|(www\.)*(google|bing)\./.test(aUrl))
     return;
   if (aTab.selected && !isBlankPageURL(aUrl)) {
-    // clean the the address bar as if the user laod about:blank tab
+    // clean the the address bar as if the user load about:blank tab
     this.selectedTab = aTab;
     this.userTypedValue = aUrl;
     gBrowser.userTypedValue = "";
@@ -227,7 +227,7 @@ Tabmix.clearUrlBar = function TMP_clearUrlBar(aTab, aUrl, aTimeOut, replaceLastT
 
 /**
  * @brief In TMP_BrowserOpenTab we empty and focus the urlbar
- *        if the user or onload from a page blur the urlbar befroe user typed new value
+ *        if the user or onload from a page blur the urlbar before user typed new value
  *        we restore the current url
  */
 Tabmix.urlBarOnBlur = function TMP_urlBarOnBlur() {
diff --git a/chrome/content/minit/minit.js b/chrome/content/minit/minit.js
index 47316ff..82af2d9 100644
--- a/chrome/content/minit/minit.js
+++ b/chrome/content/minit/minit.js
@@ -30,9 +30,9 @@ var TMP_tabDNDObserver = {
 
     tabBar.moveTabOnDragging = Tabmix.prefs.getBoolPref("moveTabOnDragging");
     // Determine what tab we're dragging over.
-    // * In tabmix tabs can have diffrent width
+    // * In tabmix tabs can have different width
     // * Point of reference is the start of the dragged tab when
-    //   draging left and the end when draging right. If that point
+    //   dragging left and the end when dragging right. If that point
     //   is before (for dragging left) or after (for dragging right)
     //   the middle of a background tab, the dragged tab would take that
     //   tab's position when dropped.
@@ -131,7 +131,7 @@ var TMP_tabDNDObserver = {
     let browser = tab.linkedBrowser;
 
     // We must not set text/x-moz-url or text/plain data here,
-    // otherwise trying to deatch the tab by dropping it on the desktop
+    // otherwise trying to detach the tab by dropping it on the desktop
     // may result in an "internet shortcut"
     dt.mozSetDataAt("text/x-moz-text-internal", browser.currentURI.spec, 0);
 
@@ -431,7 +431,7 @@ var TMP_tabDNDObserver = {
 
       // Stop the about:blank load
       newBrowser.stop();
-      // make sure it has a docshell
+      // make sure it has a docShell
       void newBrowser.docShell;
 
       let numPinned = gBrowser._numPinnedTabs;
@@ -775,9 +775,9 @@ var TMP_tabDNDObserver = {
     if (!Tabmix.prefs.getBoolPref("useFirefoxDragmark")) {
       var index = this.dragmarkindex.newIndex;
       if (index != gBrowser.tabs.length && gBrowser.tabs[index].hasAttribute("dragmark"))
-        this.removetDragmarkAttribute(gBrowser.tabs[index]);
+        this.removeDragmarkAttribute(gBrowser.tabs[index]);
       if (index !== 0 && gBrowser.tabs[index - 1].hasAttribute("dragmark"))
-        this.removetDragmarkAttribute(gBrowser.tabs[index - 1]);
+        this.removeDragmarkAttribute(gBrowser.tabs[index - 1]);
     } else {
       this.setFirefoxDropIndicator(false);
     }
@@ -789,7 +789,7 @@ var TMP_tabDNDObserver = {
     gBrowser.tabContainer._tabDropIndicator.collapsed = !val;
   },
 
-  removetDragmarkAttribute: function(tab) {
+  removeDragmarkAttribute: function(tab) {
     tab.removeAttribute("dragmark");
   },
 
@@ -931,7 +931,7 @@ Tabmix.whereToOpen = function TMP_whereToOpen(pref, altKey) {
 
   var openTabPref = typeof (pref) == "string" ? Services.prefs.getBoolPref(pref) : pref;
   if (typeof (altKey) != "undefined") {
-    // don't reuse balnk tab if the user press alt key when the pref is to open in current tab
+    // don't reuse blank tab if the user press alt key when the pref is to open in current tab
     if (altKey && !openTabPref)
       isBlankTab = false;
 
@@ -1000,7 +1000,7 @@ var TMP_TabView = {
     return firstTab;
   },
 
-  // includung _removingTabs
+  // including _removingTabs
   currentGroup: function() {
     return Array.prototype.filter.call(gBrowser.tabs, tab => !tab.hidden);
   },
@@ -1058,7 +1058,7 @@ Tabmix.navToolbox = {
     gNavToolbox.removeEventListener("beforecustomization", this, false);
     gNavToolbox.removeEventListener("aftercustomization", this, false);
 
-    // fix bug 1034394 - tab mix plus's tabmixscrollbox is not cleaned up after
+    // fix bug 1034394 - tab mix plus's tabmixScrollBox is not cleaned up after
     // uninstalling tab mix plus
     if (!Tabmix.isVersion(290)) {
       this.cleanCurrentset();
@@ -1155,7 +1155,7 @@ Tabmix.navToolbox = {
         typeof gURLBar.handleCommand == "undefined")
       return;
 
-    // onblur attribut reset each time we exit ToolboxCustomize
+    // onblur attribute reset each time we exit ToolboxCustomize
     var blur = gURLBar.getAttribute("onblur") || "";
     if (blur.indexOf("Tabmix.urlBarOnBlur") == -1)
       Tabmix.setItem(gURLBar, "onblur", blur + "Tabmix.urlBarOnBlur();");
@@ -1347,8 +1347,8 @@ Tabmix.navToolbox = {
     /**
      * we need to position three elements in TabsToolbar :
      * tabmixScrollBox, new-tab-button, and tabmix-tabs-closebutton.
-     * we resotre tabmixScrollBox positoin first since its postion is fixed,
-     * to be on the safe side we check tabmixScrollBox positoin again after we
+     * we restore tabmixScrollBox position first since its position is fixed,
+     * to be on the safe side we check tabmixScrollBox position again after we
      * restore tabmix-tabs-closebutton and new-tab-button position.
      */
     this.setScrollButtons();
diff --git a/chrome/content/minit/tabView.js b/chrome/content/minit/tabView.js
index 4475ffa..f25746a 100644
--- a/chrome/content/minit/tabView.js
+++ b/chrome/content/minit/tabView.js
@@ -193,7 +193,7 @@
 
   /* ............... TabmixSessionManager TabView Data ............... */
 
-  // winData: SessionStroe window state
+  // winData: SessionStore window state
   TabmixSessionManager._setWindowStateBusy = function(winData) {
     this._beforeRestore(winData);
     if (!this.tabViewInstalled) {
@@ -227,7 +227,7 @@
 
     // update page bounds when we overwrite tabs
     if (aOverwriteTabs || this._updateUIpageBounds)
-      this._setUIpageBounds();
+      this._setPageBounds();
 
     if (TabView._window && !aOverwriteTabs) {
       // when we don't overwriting tabs try to rearrange the groupItems
@@ -243,7 +243,7 @@
   TabmixSessionManager._tabviewData = {};
   TabmixSessionManager._groupItems = null;
 
-  // winData: SessionStroe window state
+  // winData: SessionStore window state
   TabmixSessionManager._getSessionTabviewData = function(winData) {
     let extData = winData.extData || {};
     function _fixData(id, parse, def) {
@@ -303,7 +303,7 @@
     var tabviewData;
     if (update.newGroupID) {
       // We are here only when the restored session did not have tabview data
-      // we creat new group and fill all the data
+      // we create new group and fill all the data
       tabviewData = setData(update.newGroupID);
     } else {
       tabviewData = tabdata.extData && tabdata.extData["tabview-tab"] || null;
@@ -411,11 +411,11 @@
   };
 
  /**
-  * when we append tab to this window we merge group data from the session into the curent group data
+  * when we append tab to this window we merge group data from the session into the current group data
   * loadOnStartup: array of tabs that load on startup from application
   * blankTabs: remaining blank tabs in this windows
   */
-  TabmixSessionManager._preperTabviewData = function SM__preperTabviewData(loadOnStartup, blankTabs) {
+  TabmixSessionManager._prepareTabviewData = function SM__prepareTabviewData(loadOnStartup, blankTabs) {
     if (!this.tabViewInstalled) {
       return;
     }
@@ -549,7 +549,7 @@
   /* ............... TabView Code Fix  ............... */
 
   // update page bounds when we overwrite tabs
-  TabmixSessionManager._setUIpageBounds = function SM__setUIpageBounds() {
+  TabmixSessionManager._setPageBounds = function SM__setPageBounds() {
     if (TabView._window) {
       let data = TabmixSessionData.getWindowValue(window, "tabview-ui", true);
       if (this.isEmptyObject(data))
diff --git a/chrome/content/minit/tablib.js b/chrome/content/minit/tablib.js
index d3eeee6..5ec712c 100644
--- a/chrome/content/minit/tablib.js
+++ b/chrome/content/minit/tablib.js
@@ -14,7 +14,7 @@ var tablib = { // eslint-disable-line
     this.addNewFunctionsTo_gBrowser();
   },
 
-  _loadURIWithFlagsinitialized: false,
+  _loadURIWithFlagsInitialized: false,
   setLoadURIWithFlags: function tablib_setLoadURIWithFlags(aBrowser) {
     // set init value according to lockallTabs state
     // we update this value in TabmixProgressListener.listener.onStateChange
@@ -24,9 +24,9 @@ var tablib = { // eslint-disable-line
     // added _loadURIWithFlags to browser.js (Firefox 36+)
     var obj, name;
     if (Tabmix.isVersion(360)) {
-      if (this._loadURIWithFlagsinitialized)
+      if (this._loadURIWithFlagsInitialized)
         return;
-      this._loadURIWithFlagsinitialized = true;
+      this._loadURIWithFlagsInitialized = true;
       [obj, name] = [window, "window._loadURIWithFlags"];
     } else {
       [obj, name] = [aBrowser, "browser.loadURIWithFlags"];
@@ -94,11 +94,11 @@ var tablib = { // eslint-disable-line
     var isBlankTab = gBrowser.isBlankNotBusyTab(tab);
     var isLockedTab = tab.hasAttribute("locked");
     if (!allowLoad && !isBlankTab && isLockedTab) {
-      let isFlaged = flag => Boolean(flags & Ci.nsIWebNavigation[flag]);
+      let isFlagged = flag => Boolean(flags & Ci.nsIWebNavigation[flag]);
       params.inBackground = false;
-      params.allowThirdPartyFixup = isFlaged("LOAD_FLAGS_ALLOW_THIRD_PARTY_FIXUP");
-      params.fromExternal = isFlaged("LOAD_FLAGS_FROM_EXTERNAL");
-      params.allowMixedContent = isFlaged("LOAD_FLAGS_ALLOW_MIXED_CONTENT");
+      params.allowThirdPartyFixup = isFlagged("LOAD_FLAGS_ALLOW_THIRD_PARTY_FIXUP");
+      params.fromExternal = isFlagged("LOAD_FLAGS_FROM_EXTERNAL");
+      params.allowMixedContent = isFlagged("LOAD_FLAGS_ALLOW_MIXED_CONTENT");
       return gBrowser.loadOneTab(uri, params);
     }
     browser.tabmix_allowLoad = uri == TabmixSvc.aboutBlank || !isLockedTab;
@@ -146,7 +146,7 @@ var tablib = { // eslint-disable-line
       [obj, fnName] = [Fd, "Fd.addTab"];
     } else if (Tabmix.extensions.ieTab2) {
       [obj, fnName] = [Tabmix.originalFunctions, "oldAddTab"];
-    // NRA-ILA toolbar extension raplce the original addTab function
+    // NRA-ILA toolbar extension replace the original addTab function
     } else if ("origAddTab7c3de167ed6f494aa652f11a71ecb40c" in gBrowser) {
       [obj, fnName] = [gBrowser, "origAddTab7c3de167ed6f494aa652f11a71ecb40c"];
     } else {
@@ -215,7 +215,7 @@ var tablib = { // eslint-disable-line
       return callerTrace.contain("ssi_restoreWindow", "ssi_duplicateTab");
     };
 
-    // ContextMenu Extensions raplce the original removeTab function
+    // ContextMenu Extensions replace the original removeTab function
     var _removeTab = "removeTab";
     if ("__ctxextensions__removeTab" in gBrowser)
       _removeTab = "__ctxextensions__removeTab";
@@ -233,7 +233,7 @@ var tablib = { // eslint-disable-line
        '            if ("clearTimeouts" in aTab)\n' +
        '              aTab.clearTimeouts();'
     )._replace(
-      // fix bug in TGM when closeing last tab in a group with animation
+      // fix bug in TGM when closing last tab in a group with animation
       'if (aParams)',
       'if (lastTabInGroup) {aParams ? aParams.animate = false : aParams = {animate: false}};\
        $&', {check: Tabmix.extensions.tabGroupManager}
@@ -471,7 +471,7 @@ var tablib = { // eslint-disable-line
         '  $&'
       ).toCode();
 
-      // _expandSpacerBy not exsit in Firefox 21
+      // _expandSpacerBy not exist in Firefox 21
       if (typeof tabBar._expandSpacerBy == "function") {
         Tabmix.changeCode(tabBar, "gBrowser.tabContainer._expandSpacerBy")._replace(
           '{',
@@ -796,8 +796,8 @@ var tablib = { // eslint-disable-line
 
     Tabmix.changeCode(window, "goQuitApplication")._replace(
       'var appStartup',
-      'let closedtByToolkit = Tabmix.callerTrace("toolkitCloseallOnUnload");' +
-      'if (!TabmixSessionManager.canQuitApplication(closedtByToolkit))' +
+      'let closedByToolkit = Tabmix.callerTrace("toolkitCloseallOnUnload");' +
+      'if (!TabmixSessionManager.canQuitApplication(closedByToolkit))' +
       '  return false;' +
       '$&'
     ).toCode();
@@ -989,7 +989,7 @@ var tablib = { // eslint-disable-line
           Tabmix.assert(ex);
         }
       }
-      // we need to update history title after the new page loaded for use in back/forword button
+      // we need to update history title after the new page loaded for use in back/forward button
       function updateNewHistoryTitle() {
         try {
           this.removeEventListener("SSTabRestored", updateNewHistoryTitle, true);
@@ -1472,7 +1472,7 @@ var tablib = { // eslint-disable-line
         return true;
       }
       var closing = this.closingTabsEnum;
-      // try to cach call from other extensions to warnAboutClosingTabs (before Firefox 24)
+      // try to catch call from other extensions to warnAboutClosingTabs (before Firefox 24)
       if (typeof (whatToClose) == "boolean")
         whatToClose = whatToClose ? closing.ALL_ONEXIT : closing.OTHER;
 
@@ -1655,7 +1655,7 @@ var tablib = { // eslint-disable-line
 
     Tabmix.originalFunctions.swapBrowsersAndCloseOther = gBrowser.swapBrowsersAndCloseOther;
     let swapTab = function tabmix_swapBrowsersAndCloseOther(aOurTab, aOtherTab) {
-      // Do not allow transfering a private tab to a non-private window
+      // Do not allow transferring a private tab to a non-private window
       // and vice versa.
       if (PrivateBrowsingUtils.isWindowPrivate(window) !=
           PrivateBrowsingUtils.isWindowPrivate(aOtherTab.ownerDocument.defaultView)) {
@@ -1694,7 +1694,7 @@ var tablib = { // eslint-disable-line
     };
 
     /** DEPRECATED **/
-    // we keep this function to saty compatible with other extensions that use it
+    // we keep this function to stay compatible with other extensions that use it
     gBrowser.undoRemoveTab = () => TMP_ClosedTabs.undoCloseTab();
     // Tabmix don't use this function anymore
     // but treeStyleTab extension look for it
@@ -1741,7 +1741,7 @@ var tablib = { // eslint-disable-line
 
   onTabTitleChanged: function TMP_onTabTitleChanged(aTab, aBrowser, isUrlTitle) {
     // when TabmixTabbar.widthFitTitle is true we only have width attribute after tab reload
-    // some site, like Gmail change title internaly, after load already finished and we have remove
+    // some site, like Gmail change title internally, after load already finished and we have remove
     // width attribute
     if (!TabmixTabbar.widthFitTitle || (isUrlTitle && aTab.hasAttribute("width")))
       return;
@@ -1812,7 +1812,7 @@ var tablib = { // eslint-disable-line
     // we use this flag in WindowIsClosing
     Tabmix._warnedBeforeClosing = true;
 
-    // since that some pref can changed by _onQuitRequest we catch it fisrt
+    // since that some pref can changed by _onQuitRequest we catch it first
     // by observe browser-lastwindow-close-requested
     function getSavedPref(aPrefName, type) {
       let returnVal = {saved: false};
@@ -1855,7 +1855,7 @@ var tablib = { // eslint-disable-line
       if (window.gBrowser.browsers.length < 2 || Tabmix.numberOfWindows(false, windowtype) > 1)
         return false;
 
-      // since this pref can change by _onQuitRequest we catch it fisrt
+      // since this pref can change by _onQuitRequest we catch it first
       // by observe browser-lastwindow-close-requested
       let saveSessionPref = getSavedPref("browser.startup.page", "int");
       if (saveSessionPref.saved && saveSessionPref.value == 3)
@@ -1867,7 +1867,7 @@ var tablib = { // eslint-disable-line
       // when we quit or close last browser window.
       // if "browser.showQuitWarning" is false and we close last window firefox design
       // to show warnAboutClosingTabs dialog but we block it in order to call warnAboutClosingTabs
-      // from here and catch dispaly time here.
+      // from here and catch display time here.
       return getSavedPref("browser.showQuitWarning").value;
     }
 
diff --git a/chrome/content/overlay/browser.css b/chrome/content/overlay/browser.css
index 150953d..0c26dd8 100644
--- a/chrome/content/overlay/browser.css
+++ b/chrome/content/overlay/browser.css
@@ -226,7 +226,7 @@ so display: none !important; does not hide the button */
   border-right: none;
 }
 
-/*** backword compatibility with theme that still use old tabmix tab binding ***/
+/*** backward compatibility with theme that still use old tabmix tab binding ***/
 .tabbrowser-tab:not([fadein]):not([pinned]) .tab-text-stack > .tab-progress {
   display: none !important;
 }
diff --git a/chrome/content/overlay/firefox.css b/chrome/content/overlay/firefox.css
index 2d18c5a..fb03949 100644
--- a/chrome/content/overlay/firefox.css
+++ b/chrome/content/overlay/firefox.css
@@ -16,7 +16,7 @@
   margin-top: 1px !important;
 }
 
-/* -moz-window-dragging is not recognize by Plaemoon */
+/* -moz-window-dragging is not recognize by Pale Moon */
 #main-window[tabsintitlebar][tabmix-tabbaronbottom] .tabbrowser-tabbox,
 #main-window[tabsintitlebar] #TabsToolbar[tabmix-disallow-drag] {
   -moz-window-dragging: no-drag;
diff --git a/chrome/content/places/places.js b/chrome/content/places/places.js
index b040437..4f66900 100644
--- a/chrome/content/places/places.js
+++ b/chrome/content/places/places.js
@@ -72,7 +72,7 @@ var TMP_Places = {
       ).defineProperty();
     }
 
-    // prevent error when closing window with sidbar open
+    // prevent error when closing window with sidebar open
     var docURI = window.document.documentURI;
     if (docURI == "chrome://browser/content/bookmarks/bookmarksPanel.xul" ||
         docURI == "chrome://browser/content/history/history-panel.xul") {
@@ -423,7 +423,7 @@ var TMP_Places = {
   },
 
   // extensions.tabmix.titlefrombookmark changed
-  onPreferencChanged: function(aPrefValue) {
+  onPreferenceChanged: function(aPrefValue) {
     this._titlefrombookmark = aPrefValue;
 
     if (aPrefValue) {
@@ -455,7 +455,7 @@ var TMP_Places = {
     Ci.nsINavBookmarkObserver
   ]),
 
-  addItemIdtoTabsWithUrl: function TMP_PC_addItemIdtoTabsWithUrl(aItemId, aUrl) {
+  addItemIdToTabsWithUrl: function TMP_PC_addItemIdToTabsWithUrl(aItemId, aUrl) {
     if (this.inUpdateBatch) {
       this._batchData.add.ids.push(aItemId);
       this._batchData.add.urls.push(aUrl);
@@ -478,7 +478,7 @@ var TMP_Places = {
     this.afterTabTitleChanged();
   },
 
-  updateTitleonTabs: function TMP_PC_updateTitleonTabs(aItemId) {
+  updateTabsTitleForId: function TMP_PC_updateTabsTitleForId(aItemId) {
     if (this.inUpdateBatch) {
       this._batchData.updateIDs.push(aItemId);
       return;
@@ -507,13 +507,13 @@ var TMP_Places = {
       return;
     var url = aURI ? aURI.spec : null;
     if (url && !isBlankPageURL(url))
-      this.addItemIdtoTabsWithUrl(aItemId, url);
+      this.addItemIdToTabsWithUrl(aItemId, url);
   },
 
   onItemRemoved: function TMP_PC_onItemRemoved(aItemId, aFolder, aIndex, aItemType) {
     if (aItemId == -1 || aItemType != Ci.nsINavBookmarksService.TYPE_BOOKMARK)
       return;
-    this.updateTitleonTabs(aItemId);
+    this.updateTabsTitleForId(aItemId);
   },
 
   // onItemChanged also fired when page is loaded (visited count changed ?)
@@ -524,8 +524,8 @@ var TMP_Places = {
       return;
 
     if (aProperty == "uri" && aNewValue && !isBlankPageURL(aNewValue))
-      this.addItemIdtoTabsWithUrl(aItemId, aNewValue);
-    this.updateTitleonTabs(aItemId);
+      this.addItemIdToTabsWithUrl(aItemId, aNewValue);
+    this.updateTabsTitleForId(aItemId);
   },
 
   onBeginUpdateBatch: function TMP_PC_onBeginUpdateBatch() {
@@ -542,9 +542,9 @@ var TMP_Places = {
     this.inUpdateBatch = false;
     var [updateIDs, addIDs, addURLs] = [data.updateIDs, data.add.ids, data.add.urls];
     if (addIDs.length)
-      this.addItemIdtoTabsWithUrl(addIDs, addURLs);
+      this.addItemIdToTabsWithUrl(addIDs, addURLs);
     if (updateIDs.length)
-      this.updateTitleonTabs(updateIDs);
+      this.updateTabsTitleForId(updateIDs);
 
     this._batchData = {updateIDs: [], add: {ids: [], urls: []}};
 
diff --git a/chrome/content/session/promptservice.js b/chrome/content/session/promptservice.js
index f4fb1b6..989f214 100644
--- a/chrome/content/session/promptservice.js
+++ b/chrome/content/session/promptservice.js
@@ -110,7 +110,7 @@ function prompt_init() {
   var dialog = document.documentElement;
   dialog.defaultButton = dButton;
   if (gHideElmParam == TMP_HIDE_MENUANDTEXT) { // hide menulist & text box and set focus to default Button
-    document.getElementById("space_befor_checkbox").hidden = true;
+    document.getElementById("space_before_checkbox").hidden = true;
     dialog.getButton(dButton).focus();
   }
 
diff --git a/chrome/content/session/promptservice.xul b/chrome/content/session/promptservice.xul
index 54debed..b203177 100644
--- a/chrome/content/session/promptservice.xul
+++ b/chrome/content/session/promptservice.xul
@@ -37,7 +37,7 @@
       </menulist>
       <!-- textbox -->
       <textbox id="tm_textbox" maxlength="50" oninput="inputText(this);"/>
-      <separator id="space_befor_checkbox" class="thin"/>
+      <separator id="space_before_checkbox" class="thin"/>
       <!-- checkbox -->
       <vbox id="checkboxContainer" align="start" collapsed="true">
          <checkbox id="tm_checkbox"/>
diff --git a/chrome/content/session/session.js b/chrome/content/session/session.js
index e3cfd37..a14b502 100644
--- a/chrome/content/session/session.js
+++ b/chrome/content/session/session.js
@@ -20,7 +20,7 @@ Tabmix.NO_NEED_TO_REPLACE = -1;
 var TabmixSessionManager, TabmixSessionData;
 
 /**
- *  sanitize privte data by delete the files session.rdf session.old
+ *  sanitize private data by delete the files session.rdf session.old
  */
 Tabmix.Sanitizer = {
   isSanitizeTMPwithoutPrompet: function(aOnExit) {
@@ -221,7 +221,6 @@ TabmixSessionData = {
 
 TabmixSessionManager = {
   _rdfRoot: "rdf://tabmix",
-  HSitems: 3,
   NC_TM: {},
   gSessionPath: ["", "", "", ""],
   gThisWin: null,
@@ -310,7 +309,7 @@ TabmixSessionManager = {
                                       "resource://tabmixplus/TabGroupsMigrator.jsm");
 
     // just in case tablib isn't init yet
-    // when Webmail Notifier extension istalled and user have master password
+    // when Webmail Notifier extension installed and user have master password
     // we can get here before the browser window is loaded
     tablib.init();
 
@@ -351,7 +350,7 @@ TabmixSessionManager = {
     }
 
     if (this.isPrivateWindow) {
-      // disable saveing or changeing any data on the disk in private window
+      // disable saving or changing any data on the disk in private window
       document.getElementById("tmp_contextmenu_ThisWindow").setAttribute("disabled", true);
       document.getElementById("tmp_contextmenu_AllWindows").setAttribute("disabled", true);
       document.getElementById("tmp_disableSave").setAttribute("disabled", true);
@@ -377,13 +376,13 @@ TabmixSessionManager = {
     }
 
     // If sessionStore restore the session after restart we do not need to do anything
-    // when all tabs are pinned, session resore add the home page on restart
+    // when all tabs are pinned, session restore add the home page on restart
     // prepare history sessions
     if (Tabmix.firstWindowInSession && !this.globalPrivateBrowsing &&
         !sanitized && !Tabmix.isWindowAfterSessionRestore) {
       if (this.enableManager || crashed) {
         if (crashed)
-          this.preparAfterCrash(sm_status);
+          this.prepareAfterCrash(sm_status);
         this.prepareSavedSessions();
       }
     }
@@ -513,7 +512,7 @@ TabmixSessionManager = {
     // we are on the last window........
 
     // we call Tabmix.Sanitizer.tryToSanitize from onWindowClose
-    // we don't need to show warnBeforeSaveSession dialog if we sanitize TMP without prompet on exit
+    // we don't need to show warnBeforeSaveSession dialog if we sanitize TMP without prompt on exit
     if (Services.prefs.getBoolPref("privacy.sanitize.sanitizeOnShutdown") &&
         Tabmix.Sanitizer.isSanitizeTMPwithoutPrompet(true))
       return resultData;
@@ -654,7 +653,7 @@ TabmixSessionManager = {
     let enabled = this.enableManager || this.enableBackup;
     if (enabled)
       this.saveAllWindows(this.gSessionPath[0], "windowclosed", true);
-    // cheack if all open windows are popup
+    // check if all open windows are popup
     var allPopups = enabled && !window.toolbar.visible;
     var wnd, enumerator;
     enumerator = Tabmix.windowEnumerator();
@@ -718,9 +717,9 @@ TabmixSessionManager = {
     //          sessions.crashRecovery - ok
     //          sessions.save.closedtabs - ok
     //          sessions.save.history - ok
-    //          sessions.save.permissions - ok (update evry time this function run because lock is change)
-    //          sessions.save.locked - ok (update evry time this function run because lock is change)
-    //          sessions.save.protected - ok (update evry time this function run because lock is change)
+    //          sessions.save.permissions - ok (update every time this function run because lock is change)
+    //          sessions.save.locked - ok (update every time this function run because lock is change)
+    //          sessions.save.protected - ok (update every time this function run because lock is change)
     //          sessions.save.selectedtab - ok
     // xxx      sessions.save.scrollposition - ok (update with history) // xxx need to divide it
     //          undoClose -
@@ -1000,7 +999,7 @@ TabmixSessionManager = {
     } catch (ex) {
       let decodedString;
       try {
-        // we defined lazy gette for _decode to import from Decode.jsm module
+        // we defined lazy getter for _decode to import from Decode.jsm module
         decodedString = this._decode.unescape(encodedString);
       } catch (er) {
         let msg = "Tabmix is unable to decode " + key;
@@ -1157,8 +1156,8 @@ TabmixSessionManager = {
       case "sessionstore-last-session-cleared":
         TabmixSvc.sm.lastSessionPath = null;
         break;
-      case "browser:purge-session-history": // catch sanitization
-        // curently we don't do anything on exit
+      case "browser:purge-session-history":
+        // currently we don't do anything on exit
         // if user set privacy.clearOnShutdown.history
         // we have an option not to save on exit
         if (this.enableManager || this.enableBackup) {
@@ -1190,7 +1189,7 @@ TabmixSessionManager = {
 
  /**
   * @brief           catch middle click from closed windows list,
-  *                  delete window from the list or resrore acurding to the pref
+  *                  delete window from the list or restore according to the pref
   * @param aEvent    a valid event union.
   * @returns         noting.
   *
@@ -1490,11 +1489,11 @@ TabmixSessionManager = {
   },
 
   getSessionName: function(action, old) {
-    var showChebox, closedtabMsg, saveClosedTabs = this.saveClosedtabs;
+    var showCheckbox, closedtabMsg, saveClosedTabs = this.saveClosedtabs;
     if (action != "rename" && saveClosedTabs) {
       closedtabMsg = TabmixSvc.getSMString("sm.saveClosedTab.chkbox.label");
-      showChebox = Tabmix.CHECKBOX_CHECKED;
-    } else showChebox = Tabmix.HIDE_CHECKBOX;
+      showCheckbox = Tabmix.CHECKBOX_CHECKED;
+    } else showCheckbox = Tabmix.HIDE_CHECKBOX;
     var msg = TabmixSvc.getSMString("sm.sessionName.msg0") + "\n";
     var title = TabmixSvc.getSMString("sm.sessionName.title." + action);
     var label, buttons, actionFlag;
@@ -1512,7 +1511,7 @@ TabmixSessionManager = {
       actionFlag = Tabmix.DLG_SAVE;
     }
     label = label + "\n" + sessionList.list.join("\n");
-    var result = Tabmix.promptService([Tabmix.BUTTON_OK, Tabmix.SHOW_TEXTBOX, showChebox, actionFlag],
+    var result = Tabmix.promptService([Tabmix.BUTTON_OK, Tabmix.SHOW_TEXTBOX, showCheckbox, actionFlag],
                                       [title, msg, label, closedtabMsg, buttons]);
     switch (result.button) {
       case Tabmix.BUTTON_CANCEL: return {button: result.button};
@@ -1565,7 +1564,7 @@ TabmixSessionManager = {
       return false;
 
     var overwriteWindows = this.prefBranch.getBoolPref("restore.overwritewindows") || Tabmix.singleWindowMode;
-    document.getElementById("tm-sm-OpenInCurrenWindow").setAttribute("default", overwriteWindows);
+    document.getElementById("tm-sm-OpenInCurrentWindow").setAttribute("default", overwriteWindows);
     document.getElementById("tm-sm-OpenInNewWindow").setAttribute("default", !overwriteWindows);
     document.getElementById("tm-sm-OpenInNewWindow").hidden = Tabmix.singleWindowMode;
 
@@ -1724,7 +1723,7 @@ TabmixSessionManager = {
     var path = aMenuItem.session;
     if (aRemoveSession || node.hasAttribute("sessionmanager-menu")) {
       // before we remove this session check if it is the startup session
-      // and let the user cancel the delete or choose diffrent startup session
+      // and let the user cancel the delete or choose different startup session
       var result = this.promptReplaceStartup("removeSavedSession", path);
       switch (result.button) {
         case Tabmix.BUTTON_CANCEL:
@@ -1796,9 +1795,9 @@ TabmixSessionManager = {
   },
 
   removeAllClosedWindows: function() {
-    var currenSession = this.gSessionPath[0];
-    if (!this.containerEmpty(currenSession)) {
-      let sessionContainer = this.initContainer(currenSession);
+    var currentSession = this.gSessionPath[0];
+    if (!this.containerEmpty(currentSession)) {
+      let sessionContainer = this.initContainer(currentSession);
       this.deleteWithProp(sessionContainer, "status", "saved");
       this.updateClosedWindowsMenu(true);
       this.saveStateDelayed();
@@ -2078,7 +2077,7 @@ TabmixSessionManager = {
   },
 
   // call by init on first window load after crash
-  preparAfterCrash: function SM_preparAfterCrash(status) {
+  prepareAfterCrash: function SM_preparAfterCrash(status) {
     var sessionContainer = this.initContainer(this.gSessionPath[0]);
     if (this.enableBackup) {
       var path = this._rdfRoot + "/closedSession/thisSession";
@@ -2140,7 +2139,7 @@ TabmixSessionManager = {
     var callBack = function(aResult) {
       this.afterCrashPromptCallBack(aResult);
     }.bind(this);
-    this.callBackData = {label: null, whattoLoad: "session"};
+    this.callBackData = {label: null, whatToLoad: "session"};
     this.waitForCallBack = true;
     if (!this.containerEmpty(this.gSessionPath[3])) { // if Crashed Session is not empty
       if (!this.nodeHasArc(this.gSessionPath[3], "nameExt")) {
@@ -2185,7 +2184,7 @@ TabmixSessionManager = {
                  TabmixSvc.setLabel("sm.afterCrash.button1")].join("\n");
       this.promptService([Tabmix.BUTTON_OK, Tabmix.SHOW_MENULIST, chkBoxState, Tabmix.SHOW_CLOSED_WINDOW_LIST],
                          [title, msg, "", chkBoxLabel, buttons], window, callBack);
-      this.callBackData.whattoLoad = "closedwindow";
+      this.callBackData.whatToLoad = "closedwindow";
     } else {// nothing to restore
       msg = TabmixSvc.getSMString("sm.afterCrash.msg9") + "\n" + TabmixSvc.getSMString("sm.afterCrash.msg10");
       if (!this.enableManager)
@@ -2206,7 +2205,7 @@ TabmixSessionManager = {
       } catch (ex) { }
     }
     if (aResult.button == Tabmix.BUTTON_OK) {
-      switch (this.callBackData.whattoLoad) {
+      switch (this.callBackData.whatToLoad) {
         case "session": this.loadSession(aResult.label, "firstwindowopen");
           break;
         case "closedwindow": this.openclosedwindow(aResult.label, true);
@@ -2270,7 +2269,7 @@ TabmixSessionManager = {
     // else if loadsession < 0 the session path is saved in this.gSessionPath
     var restoreFlag = this.prefBranch.getIntPref("onStart");
     if (restoreFlag > 1) {
-      // merege pinned tabs from all windows into one, other cases
+      // merge pinned tabs from all windows into one, other cases
       // handled by SessionStore
       if (this.prefBranch.getBoolPref("restore.concatenate"))
         this.deferredRestore();
@@ -2338,15 +2337,16 @@ TabmixSessionManager = {
         this.prefBranch.setIntPref("onStart.loadsession", -1);
         /* falls through */
       case -2:
-      case -1:
-        var indx = -1 * loadSession;
-        thisPath = this.gSessionPath[indx];
-        if (indx == 1 && this.lastSessionWasEmpty ||
-            this.containerEmpty(this.gSessionPath[indx])) {
+      case -1: {
+        let index = -1 * loadSession;
+        thisPath = this.gSessionPath[index];
+        if (index == 1 && this.lastSessionWasEmpty ||
+            this.containerEmpty(this.gSessionPath[index])) {
           startupEmpty = true;
         }
-        sessionIndex = sessionPath.length + indx - 3;
+        sessionIndex = sessionPath.length + index - 3;
         break;
+      }
     }
     if (restoreFlag > 0 || afterCrash || (startupEmpty && askifempty) || !loadSessionIsValid) {
       try {
@@ -2388,7 +2388,7 @@ TabmixSessionManager = {
     else if (this.waitForCallBack)
       this.deferredRestore();
     else
-      // we are here not after a callback only when the stratup file is empty
+      // we are here not after a callback only when the startup file is empty
       this.loadHomePage();
 
     this.saveStateDelayed();
@@ -2529,7 +2529,7 @@ TabmixSessionManager = {
  /*
   *  update closed window list flag 'dontLoad'
   *  all window that where closed more then 10 sec ago will mark 'dontLoad'
-  *  return true if we leftout with windows to load
+  *  return true if we left out with windows to load
   */
   updateClosedWindowList: function SM_updateClosedWindowList(aPopUp) {
     var thisSession = this.RDFService.GetResource(this.gSessionPath[0]);
@@ -2600,7 +2600,7 @@ TabmixSessionManager = {
     if (!overwriteWindow) overwriteWindow = false;
     if (typeof (saveClosedTabs) == "undefined") saveClosedTabs = this.saveClosedtabs;
     // if we going to delete close window from the list we can't use GetCount as ID,
-    // we need to save unink ID
+    // we need to save unique ID
     var winID;
     if (caller == "windowclosed" || caller == "windowbackup") winID = gBrowser.windowID;
     else winID = this.getAnonymousId();
@@ -2824,7 +2824,7 @@ TabmixSessionManager = {
   },
 
   getTabPosition: function() { // calc selected tab position if blank tab not restore
-    if (gBrowser.isBlankTab(gBrowser.mCurrentTab)) return 0; // if the current tab is blank we don't resore the index
+    if (gBrowser.isBlankTab(gBrowser.mCurrentTab)) return 0; // if the current tab is blank we don't restore the index
     var blankTab = 0;
     for (var i = 0; i < gBrowser.mCurrentTab._tPos; i++) {
       if (gBrowser.isBlankTab(gBrowser.tabs[i])) blankTab++;
@@ -2865,7 +2865,7 @@ TabmixSessionManager = {
     return savedTabs;
   },
 
-  // call from tabloaded, tabClosed, saveAllTab
+  // call from tabLoaded, tabClosed, saveAllTab
   saveTab: function SM_saveTab(aTab, rdfLabelTabs, tabContainer, needToAppend) {
     if (this.isTabPrivate(aTab))
       return false;
@@ -3032,7 +3032,7 @@ TabmixSessionManager = {
       concatenate = false;
     else
       concatenate = this.prefBranch.getBoolPref("restore.concatenate");
-    var saveBeforOverwrite = this.prefBranch.getBoolPref("restore.saveoverwrite");
+    var saveBeforeOverwrite = this.prefBranch.getBoolPref("restore.saveoverwrite");
     var overwriteTabs = this.prefBranch.getBoolPref("restore.overwritetabs");
 
     // in single window mode we restore ALL window into this window
@@ -3081,7 +3081,7 @@ TabmixSessionManager = {
                                        win.gBrowser.isBlankWindow());
       if (canOverwriteWindow) {
         // if we save overwrite windows in the closed windows list don't forget to set dontLoad==true
-        if (caller != "firstwindowopen" && saveBeforOverwrite && overwriteTabs)
+        if (caller != "firstwindowopen" && saveBeforeOverwrite && overwriteTabs)
           win.TabmixSessionManager.saveOneWindow(this.gSessionPath[0], "", true);
         win.TabmixSessionManager.loadOneWindow(winData, caller);
       } else {
@@ -3092,11 +3092,11 @@ TabmixSessionManager = {
         TabmixSvc.sm.windowToFocus = win;
       }
     });
-    // cloes extra windows if we overwrite open windows and set dontLoad==true
+    // close extra windows if we overwrite open windows and set dontLoad==true
     if (Tabmix.numberOfWindows() > 1 && overwriteWindows) {
       while (windowsList.length > 0) {
         let win = windowsList.pop();
-        if (saveBeforOverwrite) win.TabmixSessionManager.overwriteWindow = true;
+        if (saveBeforeOverwrite) win.TabmixSessionManager.overwriteWindow = true;
         else win.TabmixSessionManager.saveThisWindow = false;
         win.close();
       }
@@ -3114,9 +3114,9 @@ TabmixSessionManager = {
     if (typeof (overwriteWindows) == "undefined")
       overwriteWindows = this.prefBranch.getBoolPref("restore.overwritewindows");
     if (overwriteWindows || gBrowser.isBlankWindow() || Tabmix.singleWindowMode) {
-      let saveBeforOverwrite = this.prefBranch.getBoolPref("restore.saveoverwrite");
+      let saveBeforeOverwrite = this.prefBranch.getBoolPref("restore.saveoverwrite");
       let overwriteTabs = this.prefBranch.getBoolPref("restore.overwritetabs");
-      if (saveBeforOverwrite && overwriteTabs)
+      if (saveBeforeOverwrite && overwriteTabs)
         this.saveOneWindow(this.gSessionPath[0], "", true);
       this.loadOneWindow(winData, "openclosedwindow");
     } else {
@@ -3164,7 +3164,7 @@ TabmixSessionManager = {
         overwrite = this.prefBranch.getBoolPref("restore.overwritetabs");
         break;
       default:
-        Tabmix.log("SessionManager \n error unidentifid caller " + caller);
+        Tabmix.log("SessionManager \n error unidentified caller " + caller);
     }
     /*
       1. when open first windows overwrite tab only if they are home page, if firefox open from link or with
@@ -3186,7 +3186,7 @@ TabmixSessionManager = {
       return;
     }
 
-    // restore TabView data before we actualy load the tabs
+    // restore TabView data before we actually load the tabs
     this._setWindowStateBusy(winData);
 
     var newtabsCount = winData.tabs.length;
@@ -3212,7 +3212,7 @@ TabmixSessionManager = {
 
     var newIndex, aTab, loadOnStartup = [];
     if (newtabsCount > 0 && overwrite) {
-      // unpinned tabs reorder tabs, so we loob backward
+      // unpinned tabs reorder tabs, so we loop backward
       for (let i = gBrowser.tabs.length - 1; i >= 0; i--) {
         this.resetTab(gBrowser.tabs[i]);
       }
@@ -3229,10 +3229,10 @@ TabmixSessionManager = {
       }
       this.copyClosedTabsToSessionStore(winData, true);
       newIndex = 0;
-    } else if (newtabsCount > 0 && !overwrite) { // we use this in TGM and panorama (TabViewe)
+    } else if (newtabsCount > 0 && !overwrite) { // we use this in TGM and panorama (TabView)
       // catch blank tab for reuse
-      var blankTabs = [], blankTabsCount = 0, currentTabIsBalnk = false;
-      // unpinned tabs reorder tabs loob backward
+      var blankTabs = [], blankTabsCount = 0, currentTabIsBlank = false;
+      // unpinned tabs reorder tabs loop backward
       for (let i = gBrowser.tabs.length - 1; i >= 0; i--) {
         aTab = gBrowser.tabs[i];
         // make sure we not overwrite tab that loads from apps
@@ -3250,7 +3250,7 @@ TabmixSessionManager = {
       // make sure not to remove the current tab
       let index = blankTabs.indexOf(cTab);
       if (index > -1) {
-        currentTabIsBalnk = true;
+        currentTabIsBlank = true;
         blankTabs.unshift(blankTabs.splice(index, 1)[0]);
       }
       // remove extra tabs
@@ -3267,7 +3267,7 @@ TabmixSessionManager = {
       var openTabNext = Tabmix.getOpenTabNextPref();
       if (this.tabViewInstalled) {
         // fix and merge session Tabview data with current window Tabview data
-        this._preperTabviewData(loadOnStartup, blankTabs);
+        this._prepareTabviewData(loadOnStartup, blankTabs);
         if (this.groupUpdates.hideSessionActiveGroup) {
           restoreSelect = false;
           lastSelectedIndex = 0;
@@ -3281,7 +3281,7 @@ TabmixSessionManager = {
       let newTotalTabsCount = tabsCount - blankTabsCount + newtabsCount;
 
       // we don't need to move tab after itself
-      if (currentTabIsBalnk)
+      if (currentTabIsBlank)
         blankTabs.shift();
 
       let multipleTabsOnStartUp = caller == "firstwindowopen" && gBrowser.tabs.length > 1;
@@ -3312,7 +3312,7 @@ TabmixSessionManager = {
           cTab._tPos + 1 : tabsCount - blankTabsCount;
       }
       if (restoreSelect && !multipleTabsOnStartUp) {
-        if (currentTabIsBalnk) { // if the current tab is not blank select new tab
+        if (currentTabIsBlank) { // if the current tab is not blank select new tab
           if (openTabNext && newPos > 0)
             newPos--;
           // move selected tab to place
@@ -3476,7 +3476,7 @@ TabmixSessionManager = {
     // Make sure that set/getTabValue will set/read the correct data by
     // wiping out any current value in tab.__SS_extdata.
     delete aTab.__SS_extdata;
-    // delete any sesionRestore data
+    // delete any sessionRestore data
     if (!Tabmix.isVersion(410))
       delete browser.__SS_data;
 
@@ -3503,7 +3503,7 @@ TabmixSessionManager = {
   },
 
   setStripVisibility: function(tabCount) {
-    // unhide the tab bar
+    // un-hide the tab bar
     if (tabCount > 1 && Tabmix.prefs.getIntPref("hideTabbar") != 2 &&
         !gBrowser.tabContainer.visible) {
       gBrowser.tabContainer.visible = true;
@@ -3646,10 +3646,10 @@ TabmixSessionManager = {
     }
   },
 
-  getSessionsBackupDir: function SM_getSessionsBackupDir(aCretate) {
+  getSessionsBackupDir: function SM_getSessionsBackupDir(aCreate) {
     var sessionsBackupDir = this.profileDir;
     sessionsBackupDir.append("sessionbackups");
-    if (aCretate && !sessionsBackupDir.exists())
+    if (aCreate && !sessionsBackupDir.exists())
       sessionsBackupDir.create(Ci.nsIFile.DIRECTORY_TYPE, parseInt("0700", 8));
     return sessionsBackupDir;
   },
@@ -3698,7 +3698,7 @@ TabmixSessionManager = {
     if (!sessionsBackupDir.exists())
       return; // unable to create directory!
 
-    // construct the new leafname
+    // construct the new leaf name
     // Use YYYY-MM-DD (ISO 8601) as it doesn't contain illegal characters
     // and makes the alphabetical order of multiple backup files more useful.
     var d = new Date();
@@ -3813,7 +3813,7 @@ TabmixSessionManager = {
 /**
  * add backward compatibility getters to some of the main object/function/variable
  * that we changed from version 0.3.8.5pre.110123a
- * we only add this getters to objects the arn't in the name space
+ * we only add this getters to objects the aren't in the name space
  */
 Tabmix.backwardCompatibilityGetter(window, "SessionData", "TabmixSessionData");
 Tabmix.backwardCompatibilityGetter(window, "SessionManager", "TabmixSessionManager");
diff --git a/chrome/content/session/sessionStore.js b/chrome/content/session/sessionStore.js
index 341ae57..65d6aee 100644
--- a/chrome/content/session/sessionStore.js
+++ b/chrome/content/session/sessionStore.js
@@ -118,7 +118,7 @@ var TMP_SessionStore = {
     TabmixSvc.sm.settingPreference = true;
     // if session manager extension is install disable TMP session manager
     if (msgNo == -1 || Tabmix.extensions.sessionManager) {
-      // update session manager settings accourding to current tabmix settings
+      // update session manager settings according to current tabmix settings
       if (TMP_manager_enabled) {
         Services.prefs.setBoolPref(TMP_SS_MANAGER, false);
         switch (Tabmix.prefs.getIntPref("sessions.onStart")) {
@@ -149,7 +149,7 @@ var TMP_SessionStore = {
       TabmixSvc.sm.settingPreference = false;
     } else if (this.isSessionStoreEnabled()) {
       // ask the user to choose between TMP session manager and sessionstore
-      // we use non modal promptService on start up, so we disabled Tabmix session managerto let the startup
+      // we use non modal promptService on start up, so we disabled Tabmix session manager to let the startup
       // process continue and set the appropriate preference after the dialog prompt dismissed.
       if (start) {
         Services.prefs.setBoolPref(TMP_SS_MANAGER, false);
@@ -215,7 +215,7 @@ var TMP_SessionStore = {
       Tabmix.isWindowAfterSessionRestore = afterSessionRestore;
     else {
       // calling doRestore before sessionstartup finished to read
-      // sessionstroe.js file throw error since Firefox 28, and force
+      // sessionStore.js file throw error since Firefox 28, and force
       // syncRead in Firefox 25-27
       XPCOMUtils.defineLazyGetter(Tabmix, "isWindowAfterSessionRestore", function() {
         let ss = Cc["@mozilla.org/browser/sessionstartup;1"]
@@ -467,7 +467,7 @@ var TMP_ClosedTabs = {
           this.removeAllClosedTabs();
           break;
         } else if (aIndex == -2) {
-          this.SSS_restoerAllClosedTabs();
+          this.SSS_restoreAllClosedTabs();
           break;
         }
         // else do the default
@@ -512,7 +512,7 @@ var TMP_ClosedTabs = {
     return gBrowser.duplicateTabToWindow(gBrowser.mCurrentTab, null, state);
   },
 
-  SSS_restoerAllClosedTabs: function ct_SSS_restoerAllClosedTabs() {
+  SSS_restoreAllClosedTabs: function ct_SSS_restoreAllClosedTabs() {
     var closedTabCount = this.count;
     if (!PlacesUIUtils._confirmOpenInTabs(closedTabCount))
       return;
@@ -568,8 +568,8 @@ var TMP_ClosedTabs = {
     var newTab = aBlankTabToReuse ||
         gBrowser.addTab("about:blank", {skipAnimation: tabToRemove || skipAnimation, dontMove: true});
     newTab.linkedBrowser.stop();
-    // if tababr is hidden when there is only one tab and
-    // we replace that tab with new one close the current tab fast so the tab bar don't have time to reveale
+    // if tabbar is hidden when there is only one tab and
+    // we replace that tab with new one close the current tab fast so the tab bar don't have time to reveals
     if (tabToRemove) {
       gBrowser.removeTab(tabToRemove, {animate: false});
     }
@@ -894,7 +894,7 @@ var TabmixConvertSession = {
     };
     var history = TabmixSessionManager.getLiteralValue(rdfNodeTab, "history");
     var tmpData = history.split("|-|");
-    var sep = tmpData.shift(); // remove seperator from data
+    var sep = tmpData.shift(); // remove separator from data
     tmpData = tmpData.join("|-|");
     // if all history data was encoded (file saved with version
     // 0.4.1.2pre.131006a1 or newer, changeset 684a4b2302e4)
diff --git a/chrome/content/tab/scrollbox.xml b/chrome/content/tab/scrollbox.xml
index 4691a10..fe8ac91 100644
--- a/chrome/content/tab/scrollbox.xml
+++ b/chrome/content/tab/scrollbox.xml
@@ -362,7 +362,7 @@
           if (this.orient == "vertical")
             return;
 
-          Tabmix.tabsUtils.adjustNewtabButtonvisibility();
+          Tabmix.tabsUtils.adjustNewtabButtonVisibility();
           var tabs = this._getScrollableElements();
           if (!tabs.length)
             return;
diff --git a/chrome/content/tabmix.xul b/chrome/content/tabmix.xul
index e854ebb..203d369 100644
--- a/chrome/content/tabmix.xul
+++ b/chrome/content/tabmix.xul
@@ -328,7 +328,7 @@
       <menupopup id="tm_sessionmanagerContextMenu"
                   onpopupshowing="return TabmixSessionManager.updateSessionMenu(this);"
                   onpopuphidden="Tabmix.hidePopup(this);">
-        <menuitem id="tm-sm-OpenInCurrenWindow" label="&sm.context.overwrite;" accesskey="&sm.context.overwrite.key;"
+        <menuitem id="tm-sm-OpenInCurrentWindow" label="&sm.context.overwrite;" accesskey="&sm.context.overwrite.key;"
                   oncommand="TabmixSessionManager.restoreSession(this.parentNode.triggerNode, true);"/>
         <menuitem id="tm-sm-OpenInNewWindow" label="&sm.context.restore.new;" accesskey="&sm.context.restore.newkey;"
                   oncommand="TabmixSessionManager.restoreSession(this.parentNode.triggerNode, false);"/>
diff --git a/chrome/content/utils.js b/chrome/content/utils.js
index 7fa2de9..51d318d 100644
--- a/chrome/content/utils.js
+++ b/chrome/content/utils.js
@@ -221,7 +221,7 @@ var Tabmix = {
   // caller list
   _getMethod: function TMP_console_wrapper(id, args) {
     if (["changeCode", "setNewFunction", "nonStrictMode"].indexOf(id) > -1) {
-      this.installeChangecode();
+      this.installChangecode();
       return this[id].apply(this, args);
     }
     if (typeof TabmixSvc.console[id] == "function") {
@@ -231,9 +231,9 @@ var Tabmix = {
     return null;
   },
 
-  installeChangecode: function() {
+  installChangecode: function() {
     Services.scriptloader.loadSubScript("chrome://tabmixplus/content/changecode.js", window);
-    this.installeChangecode = function() {};
+    this.installChangecode = function() {};
   },
 
   _init: function() {
diff --git a/chrome/locale/en-US/pref-tabmix.dtd b/chrome/locale/en-US/pref-tabmix.dtd
index 1897d7e..7948b0d 100644
--- a/chrome/locale/en-US/pref-tabmix.dtd
+++ b/chrome/locale/en-US/pref-tabmix.dtd
@@ -20,7 +20,7 @@
 <!ENTITY linkTarget.accesskey "C">
 <!ENTITY divertedWindowOpen.label "JavaScript & Popup restriction:">
 <!ENTITY divertedWindowOpen.all "Open all popups in tabs">
-<!ENTITY divertedWindowOpen.some "Allows resized popups">
+<!ENTITY divertedWindowOpen.some "Allows resize popups">
 <!ENTITY divertedWindowOpen.none "Allows all popups">
 <!ENTITY linkTarget.label "Open links with a target attribute in current tab">
 <!ENTITY targetIsFrame.label "Open links with target to existing frame in the current tab">
diff --git a/chrome/skin/app_version/39.0/tabStyles.css b/chrome/skin/app_version/39.0/tabStyles.css
index 9e9e803..34dd6a5 100644
--- a/chrome/skin/app_version/39.0/tabStyles.css
+++ b/chrome/skin/app_version/39.0/tabStyles.css
@@ -113,8 +113,8 @@
 #tabbrowser-tabs[tabmix_unloadedStyle~="aus"] > .tabbrowser-tab:not([visuallyselected="true"])[tabmix_tabState="unloaded"] > .tab-stack > .tab-background > .tab-background-end::before,
 #tabbrowser-tabs[tabmix_unreadStyle~="aus"] > .tabbrowser-tab:not([visuallyselected="true"])[tabmix_tabState="unread"] > .tab-stack > .tab-background > .tab-background-end::before,
 #tabbrowser-tabs[tabmix_otherStyle~="aus"] > .tabbrowser-tab:not([visuallyselected="true"]):not([tabmix_tabState]) > .tab-stack > .tab-background > .tab-background-end::before {
-  content: "" !important;  /* this alrady exist for windows check in Mac and Linux*/
-  display: -moz-box !important; /* this alrady exist for windows check in Mac and Linux*/
+  content: "" !important;  /* this already exist for windows check in Mac and Linux*/
+  display: -moz-box !important; /* this already exist for windows check in Mac and Linux*/
   background-color: transparent !important;
 }
 
@@ -206,7 +206,7 @@
   border-bottom-right-radius: 15px;
 }
 
-/* fix for hoverd tab that is before or after selected tab */
+/* fix for hovered tab that is before or after selected tab */
 #tabbrowser-tabs:not([movingtab])[tabmix_unloadedStyle~="aus"] > .tabbrowser-tab:not([visuallyselected="true"])[tabmix_tabState="unloaded"][afterselected-visible="true"]:hover > .tab-stack > .tab-background > .tab-background-start,
 #tabbrowser-tabs:not([movingtab])[tabmix_unreadStyle~="aus"] > .tabbrowser-tab:not([visuallyselected="true"])[tabmix_tabState="unread"][afterselected-visible="true"]:hover > .tab-stack > .tab-background > .tab-background-start,
 #tabbrowser-tabs:not([movingtab])[tabmix_otherStyle~="aus"] > .tabbrowser-tab:not([visuallyselected="true"]):not([tabmix_tabState])[afterselected-visible="true"]:hover > .tab-stack > .tab-background > .tab-background-start,
diff --git a/chrome/skin/app_version/39.0/win/tabStyles.css b/chrome/skin/app_version/39.0/win/tabStyles.css
index 244a553..4a68b84 100644
--- a/chrome/skin/app_version/39.0/win/tabStyles.css
+++ b/chrome/skin/app_version/39.0/win/tabStyles.css
@@ -17,7 +17,7 @@
   clip-path: none !important;
 }
 
-/* Override Windows 10 rulse */
+/* Override Windows 10 rules */
 @media not all and (-moz-os-version: windows-xp) {
   @media not all and (-moz-os-version: windows-vista) {
     @media not all and (-moz-os-version: windows-win7) {
diff --git a/chrome/skin/app_version/all/linux/browser.css b/chrome/skin/app_version/all/linux/browser.css
index ca68331..0a5cb03 100644
--- a/chrome/skin/app_version/all/linux/browser.css
+++ b/chrome/skin/app_version/all/linux/browser.css
@@ -46,7 +46,7 @@
 /*  Tab scrollbox arrow buttons - fix border */
 
 /* this rule make hover active on the button
- * the default button don't change on hover, so we add the next rule to hide the eefect
+ * the default button don't change on hover, so we add the next rule to hide the effect
  */
 #tabmixScrollBox[flowing=scrollbutton] > .scrollbutton-up:not([disabled]),
 #tabmixScrollBox[flowing=scrollbutton] > .scrollbutton-down:not([disabled]),
diff --git a/chrome/skin/app_version/before39.0/tabStyles.css b/chrome/skin/app_version/before39.0/tabStyles.css
index 2908958..f2a8164 100644
--- a/chrome/skin/app_version/before39.0/tabStyles.css
+++ b/chrome/skin/app_version/before39.0/tabStyles.css
@@ -111,8 +111,8 @@
 #tabbrowser-tabs[tabmix_unloadedStyle~="aus"] > .tabbrowser-tab:not([selected="true"])[tabmix_tabState="unloaded"] > .tab-stack > .tab-background > .tab-background-end::before,
 #tabbrowser-tabs[tabmix_unreadStyle~="aus"] > .tabbrowser-tab:not([selected="true"])[tabmix_tabState="unread"] > .tab-stack > .tab-background > .tab-background-end::before,
 #tabbrowser-tabs[tabmix_otherStyle~="aus"] > .tabbrowser-tab:not([selected="true"]):not([tabmix_tabState]) > .tab-stack > .tab-background > .tab-background-end::before {
-  content: "" !important;  /* this alrady exist for windows check in Mac and Linux*/
-  display: -moz-box !important; /* this alrady exist for windows check in Mac and Linux*/
+  content: "" !important;  /* this already exist for windows check in Mac and Linux*/
+  display: -moz-box !important; /* this already exist for windows check in Mac and Linux*/
   background-color: transparent !important;
 }
 
@@ -204,7 +204,7 @@
   border-bottom-right-radius: 15px;
 }
 
-/* fix for hoverd tab that is before or after selected tab */
+/* fix for hovered tab that is before or after selected tab */
 #tabbrowser-tabs:not([movingtab])[tabmix_unloadedStyle~="aus"] > .tabbrowser-tab:not([selected="true"])[tabmix_tabState="unloaded"][afterselected-visible="true"]:hover > .tab-stack > .tab-background > .tab-background-start,
 #tabbrowser-tabs:not([movingtab])[tabmix_unreadStyle~="aus"] > .tabbrowser-tab:not([selected="true"])[tabmix_tabState="unread"][afterselected-visible="true"]:hover > .tab-stack > .tab-background > .tab-background-start,
 #tabbrowser-tabs:not([movingtab])[tabmix_otherStyle~="aus"] > .tabbrowser-tab:not([selected="true"]):not([tabmix_tabState])[afterselected-visible="true"]:hover > .tab-stack > .tab-background > .tab-background-start,
diff --git a/chrome/skin/preferences.css b/chrome/skin/preferences.css
index 30b010f..3e4f5c5 100644
--- a/chrome/skin/preferences.css
+++ b/chrome/skin/preferences.css
@@ -216,7 +216,7 @@ tabbox > tabs {
   display: none !important;
 }
 
-groupbox[TSTinstalled] label[TSTdisabled="true"] {
+groupbox[tstInstalled] label[TSTdisabled="true"] {
   color: GrayText;
 }
 
@@ -278,13 +278,13 @@ tabbox > tabpanels {
 }
 
 /* session panel */
-#sesionsPanel:not([manager]),
-#sesionsPanel[manager=tabmix] .firefox,
-#sesionsPanel[manager=firefox] .tabmix {
+#sessionsPanel:not([manager]),
+#sessionsPanel[manager=tabmix] .firefox,
+#sessionsPanel[manager=firefox] .tabmix {
   display: none;
 }
 
-#sesionsPanel > groupbox > vbox {
+#sessionsPanel > groupbox > vbox {
   height: 55px;
 }
 
@@ -294,7 +294,7 @@ tabbox > tabpanels {
   margin-bottom: 2px;
 }
 
-#sesionsPanel[manager=firefox] tab.firefox {
+#sessionsPanel[manager=firefox] tab.firefox {
   visibility: hidden;
 }
 
diff --git a/chrome/skin/renameTab.css b/chrome/skin/renameTab.css
index 81e234a..1383421 100644
--- a/chrome/skin/renameTab.css
+++ b/chrome/skin/renameTab.css
@@ -12,7 +12,7 @@
 #tabmixRenametab_defaultField {
   cursor: default;
   background-color: -moz-dialog;
-  color: graytext;
+  color: GrayText;
 }
 
 #tabmixRenametab_panel > spacer {
diff --git a/defaults/preferences/tabmix.js b/defaults/preferences/tabmix.js
index ee601d5..25aeee2 100644
--- a/defaults/preferences/tabmix.js
+++ b/defaults/preferences/tabmix.js
@@ -63,10 +63,10 @@ pref("extensions.tabmix.hideAllTabsButton", false);
 pref("extensions.tabmix.newTabButton", true);
 /*
 2009-01-31
-repalced with extensions.tabmix.newTabButton.position
+replaced with extensions.tabmix.newTabButton.position
 0 - Left side
 1 - Right side
-2 - After last tab (default) - for version befor Fx 3.1 2 - Right side
+2 - After last tab (default) - for version before Fx 3.1 2 - Right side
 pref("extensions.tabmix.newTabButton.leftside", false);
 */
 pref("extensions.tabmix.newTabButton.position", 2);
@@ -223,6 +223,7 @@ pref("extensions.tabmix.middleclickDelete", true);
 pref("extensions.tabmix.optionsToolMenu", true);
 
 pref("extensions.tabmix.enablefiletype", true);
+// noinspection SpellCheckingInspection
 pref("extensions.tabmix.filetype", "xpi zip rar exe tar jar gzip gz ace bin doc docx xls xlsx mdb ppt iso 7z cab arj lzh uue torrent /&disp=attd&/ /php?attachmentid=.*/ /php?act=Attach&type=post&id=.*/ /download.php?*/");
 
 pref("extensions.{dc572301-7619-498c-a57d-39143191b318}.description", "chrome://tabmixplus/locale/tabmix.properties");
diff --git a/modules/TabGroupsMigrator.jsm b/modules/TabGroupsMigrator.jsm
index 19365d5..083b94f 100644
--- a/modules/TabGroupsMigrator.jsm
+++ b/modules/TabGroupsMigrator.jsm
@@ -105,7 +105,7 @@ this.TabmixGroupsMigrator = {
     };
 
     try {
-      // we run this function before preparAfterCrash and prepareSavedSessions
+      // we run this function before prepareAfterCrash and prepareSavedSessions
       // we need to backup 2 last session, if last session was crashed backup
       // one more older session
       let index = isAfterCrash ? 1 : 0;
diff --git a/modules/extensions/TabGroupsManager.jsm b/modules/extensions/TabGroupsManager.jsm
index 45a44a1..7e87c07 100644
--- a/modules/extensions/TabGroupsManager.jsm
+++ b/modules/extensions/TabGroupsManager.jsm
@@ -103,7 +103,7 @@ this.TMP_TabGroupsManager = {
       'if (false) {'
     )._replace(
       'TMP_ClosedTabs.setButtonDisableState();',
-      '  if (_restoreSelect && (overwrite || (!concatenate && !currentTabIsBalnk)))' +
+      '  if (_restoreSelect && (overwrite || (!concatenate && !currentTabIsBlank)))' +
       '    this.updateSelected(newIndex + _lastSelectedIndex, overwrite ||' +
       '                        caller=="firstwindowopen" || caller=="windowopenedbytabmix");' +
       '  $&'

diff --git a/chrome/content/tab/tab.js b/chrome/content/tab/tab.js
index 1725c55..e229b9e 100644
--- a/chrome/content/tab/tab.js
+++ b/chrome/content/tab/tab.js
@@ -73,7 +73,7 @@ var TabmixTabbar = {
       let useTabmixButtons = tabscroll > this.SCROLL_BUTTONS_LEFT_RIGHT;
       let overflow = Tabmix.tabsUtils.overflow;
 
-      // from Firefox 4.0+ on we add dynamicly scroll buttons on TabsToolbar.
+      // from Firefox 4.0+ on we add dynamically scroll buttons on TabsToolbar.
       let tabmixScrollBox = document.getElementById("tabmixScrollBox");
       if (tabmixScrollBox) // just in case our box is missing
         Tabmix.tabsUtils.updateScrollButtons(useTabmixButtons);
@@ -81,7 +81,7 @@ var TabmixTabbar = {
       if (isMultiRow || prevTabscroll == this.SCROLL_BUTTONS_MULTIROW) {
         // temporarily hide vertical scroll button.
         // visible button can interfere with row height calculation.
-        // remove the collapsed attribut after updateVerticalTabStrip
+        // remove the collapsed attribute after updateVerticalTabStrip
         Tabmix.setItem(tabmixScrollBox, "collapsed", true);
       }
 
@@ -112,7 +112,7 @@ var TabmixTabbar = {
                     (tabBar.mTabMaxWidth != tabBar.mTabMinWidth);
     if (!Tabmix.extensions.verticalTabBar) {
       if (start) {
-        // Don't change tabstip orient on start before sessionStore ends.
+        // Don't change tabstrip orient on start before sessionStore ends.
         // if we set orient to vertical before sessionStore finish
         // sessionStore don't select the selected tab from last session.
         setTimeout(() => Tabmix.tabsUtils.setTabStripOrient(), 0);
@@ -186,7 +186,7 @@ var TabmixTabbar = {
     var tabBar = gBrowser.tabContainer;
     if (this.isMultiRow) {
       //XXX we only need setFirstTabInRow from here when tab width changed
-      // so if widthFitTitle is false we need to call it if we actualy change the width
+      // so if widthFitTitle is false we need to call it if we actually change the width
       // for other chases we need to call it when we change title
       if (tabBar.mTabstrip.orient == "vertical") {
         this.setFirstTabInRow();
@@ -197,11 +197,11 @@ var TabmixTabbar = {
         this.setFirstTabInRow();
       }
     } else {
-      Tabmix.tabsUtils.adjustNewtabButtonvisibility();
+      Tabmix.tabsUtils.adjustNewtabButtonVisibility();
     }
   },
 
-  // in Firefox 4.0+ rowheight can change when TabsInTitlebar or TabsOnTop
+  // in Firefox 4.0+ row height can change when TabsInTitlebar or TabsOnTop
   _tabsPosition: "tabsonbottom",
   getTabsPosition: function TMP_getTabsPosition() {
     let tabsPosition, docElement = document.documentElement;
@@ -264,7 +264,7 @@ var TabmixTabbar = {
       if (Tabmix.tabsUtils.tabstripInnerbox) {
         let height = Tabmix.tabsUtils.tabstripInnerbox.getBoundingClientRect().height;
         if (tabBar.getAttribute("multibar") == "scrollbar") {
-          // We can get here if we switch to diffrent tabs position while in multibar
+          // We can get here if we switch to different tabs position while in multibar
           let rowHeight = height / Tabmix.tabsUtils.lastTabRowNumber;
           newHeight = rowHeight * aRows;
         } else {
@@ -318,8 +318,8 @@ var TabmixTabbar = {
       tabsToolbar.style.setProperty("height", newTabbarHeight + "px", "important");
     }
 
-    // experimental - for theme that put tababr above the menus
-    // curently its only work with Vfox3 theme
+    // experimental - for theme that put tabbar above the menus
+    // currently its only work with Vfox3 theme
     if (tabstrip.boxObject.y <= gNavToolbox.boxObject.y) {
       let skin = Services.prefs.getCharPref("general.skins.selectedSkin");
       let themes = /^(Vfox3)/;
@@ -383,7 +383,7 @@ var TabmixTabbar = {
         }, 0);
       }
     }
-    /// maybe we cad add this to the popupshing / or as css rule ?
+    /// maybe we cad add this to the popupshowing / or as css rule ?
     Tabmix.setItem("alltabs-popup", "position",
         (window.windowState != window.STATE_MAXIMIZED || this.position == 1) ? "start_before" : "after_end");
   },
@@ -632,7 +632,7 @@ Tabmix.tabsUtils = {
     let onLeft = Tabmix.defaultCloseButtons && Tabmix.prefs.getBoolPref("tabs.closeButtons.onLeft");
     this.tabBar.setAttribute("closebuttons-side", onLeft ? "left" : "right");
 
-    // mCloseButtons is not in firefox code sinc Firefox 31 bug 865826
+    // mCloseButtons is not in firefox code since Firefox 31 bug 865826
     this.tabBar.mCloseButtons = Tabmix.prefs.getIntPref("tabs.closeButtons");
     this._keepLastTab = Tabmix.prefs.getBoolPref("keepLastTab");
     this.closeButtonsEnabled = Tabmix.prefs.getBoolPref("tabs.closeButtons.enable");
@@ -783,8 +783,8 @@ Tabmix.tabsUtils = {
       return this.tabBar.getAttribute("multibar");
     this._inUpdateVerticalTabStrip = true;
 
-    // we must adjustNewtabButtonvisibility before get lastTabRowNumber
-    this.adjustNewtabButtonvisibility();
+    // we must adjustNewtabButtonVisibility before get lastTabRowNumber
+    this.adjustNewtabButtonVisibility();
     // this.lastTabRowNumber is null when we hide the tabbar
     let rows = aReset || this.tabBar.childNodes.length == 1 ? 1 : (this.lastTabRowNumber || 1);
 
@@ -832,12 +832,12 @@ Tabmix.tabsUtils = {
               timeout = 0;
           }
           this.adjustNewtabButtonTimeout = setTimeout(function() {
-            this.adjustNewtabButtonvisibility();
+            this.adjustNewtabButtonVisibility();
             this.adjustNewtabButtonTimeout = null;
           }.bind(this), timeout);
         }
       } else {
-        this.adjustNewtabButtonvisibility();
+        this.adjustNewtabButtonVisibility();
       }
     }
 
@@ -846,7 +846,7 @@ Tabmix.tabsUtils = {
   },
 
   setTabStripOrient: function() {
-    // we can't set dispaly:block and orient=vertical when widthFitTitle is false
+    // we can't set display:block and orient=vertical when widthFitTitle is false
     // and we are in one row.
     let vertical = TabmixTabbar.isMultiRow &&
         (TabmixTabbar.widthFitTitle || this.tabBar.hasAttribute("multibar"));
@@ -860,7 +860,7 @@ Tabmix.tabsUtils = {
    * in the current row. we don't want the button to be on the next row when the
    * tab is on the current row
    */
-  adjustNewtabButtonvisibility: function() {
+  adjustNewtabButtonVisibility: function() {
     if (!TabmixTabbar.isMultiRow && this.tabBar.mTabstrip.orient == "vertical")
       return;
 
@@ -899,7 +899,7 @@ Tabmix.tabsUtils = {
     //         B: 2 last tabs are NOT in the same row:
     //            check if we have room for the last tab + button after
     //            previous to last tab.
-    // ignor the case that this tab width is larger then the tabbar
+    // ignore the case that this tab width is larger then the tabbar
     let previousTab = Tabmix.visibleTabs.previous(lastTab);
     if (!previousTab) {
       this.disAllowNewtabbutton = false;
@@ -908,9 +908,9 @@ Tabmix.tabsUtils = {
 
     // buttons that are not on TabsToolbar or not visible are null
     let newTabButtonWidth = function(aOnSide) {
-      let width = 0, privatTabButton = TabmixTabbar.newPrivateTabButton();
-      if (privatTabButton) {
-        width += aOnSide ? privatTabButton.boxObject.width :
+      let width = 0, privateTabButton = TabmixTabbar.newPrivateTabButton();
+      if (privateTabButton) {
+        width += aOnSide ? privateTabButton.boxObject.width :
         Tabmix.afterTabsButtonsWidth[1];
       }
       if (Tabmix.sideNewTabButton) {
@@ -953,7 +953,7 @@ Tabmix.tabsUtils = {
 
   set overflow(val) {
     // don't do anything if other extensions set orient to vertical
-    // when we arn't use it.
+    // when we aren't use it.
     if (!TabmixTabbar.isMultiRow && this.tabBar.mTabstrip.orient == "vertical")
       return val;
 
@@ -1103,7 +1103,7 @@ Tabmix.bottomToolbarUtils = {
       return;
     }
     this.initialized = true;
-    //XXX we don't check for aEvent.target != window to catch changs in
+    //XXX we don't check for aEvent.target != window to catch changes in
     // browser-bottombox. try to improve it...
     window.addEventListener("resize", this, false);
   },
@@ -1270,7 +1270,7 @@ gTMPprefObserver = {
     var prefValue, value;
     switch (prefName) {
       case "extensions.tabmix.titlefrombookmark":
-        TMP_Places.onPreferencChanged(Services.prefs.getBoolPref(prefName));
+        TMP_Places.onPreferenceChanged(Services.prefs.getBoolPref(prefName));
         break;
       case "extensions.tabmix.tabbar.click_dragwindow":
         this.setTabbarDragging(Services.prefs.getBoolPref(prefName));
@@ -1348,7 +1348,7 @@ gTMPprefObserver = {
       case "extensions.tabmix.hideIcons":
         this.setMenuIcons();
         break;
-      // tab appearnce
+      // tab appearance
       case "extensions.tabmix.currentTab":
       case "extensions.tabmix.unloadedTab":
       case "extensions.tabmix.unreadTab":
@@ -1482,7 +1482,7 @@ gTMPprefObserver = {
         }
         break;
       case "browser.sessionstore.max_tabs_undo": {
-        // Firefox's sessionStore mainain the right amount
+        // Firefox's sessionStore maintain the right amount
         prefValue = Services.prefs.getIntPref(prefName);
         if (Tabmix.prefs.getBoolPref("undoClose") != (prefValue > 0))
           Tabmix.prefs.setBoolPref("undoClose", prefValue > 0);
@@ -1588,7 +1588,7 @@ gTMPprefObserver = {
           Services.prefs.setBoolPref(prefName, false);
           return;
         }
-        // multi-rows total heights can be diffrent when tabs are on top
+        // multi-rows total heights can be different when tabs are on top
         if (TabmixTabbar.visibleRows > 1) {
           TabmixTabbar.setHeight(1, true);
           Tabmix.tabsUtils.updateVerticalTabStrip();
@@ -1623,10 +1623,10 @@ gTMPprefObserver = {
     Tabmix.setItem(TabsToolbar, "tabmix-disallow-drag", !allowDrag || null);
   },
 
-  getStyleSheets: function TMP_PO_getStyleSheet(aHerf, aFirst) {
+  getStyleSheets: function TMP_PO_getStyleSheet(aHref, aFirst) {
     var styleSheet = [];
     for (let i = 0; i < document.styleSheets.length; ++i) {
-      if (document.styleSheets[i].href == aHerf) {
+      if (document.styleSheets[i].href == aHref) {
         styleSheet.push(document.styleSheets[i]);
         if (aFirst)
           break;
@@ -1908,7 +1908,7 @@ gTMPprefObserver = {
     newRule = newRule.replace("#1", _min).replace("#2", _max);
     this.insertRule(newRule, "width");
 
-    // rule for controling moz-margin-start when we have pinned tab in multi-row
+    // rule for controlling moz-margin-start when we have pinned tab in multi-row
     let marginStart = '#tabbrowser-tabs[positionpinnedtabs] > ' +
                       '.tabbrowser-tab[tabmix-firstTabInRow="true"]{-moz-margin-start: 0px;}';
     this.insertRule(marginStart, "tabmix-firstTabInRow");
@@ -1942,7 +1942,7 @@ gTMPprefObserver = {
     let enabled = Tabmix.prefs.getBoolPref(ruleName);
     if (enabled) {
       let prefValues = TabmixSvc.tabStylePrefs[ruleName];
-      // set bold, italic and underline only when we control the sytle
+      // set bold, italic and underline only when we control the style
       // to override theme default rule if exist
       attribValue = [prefValues.bold ? "bold" : "not-bold",
                prefValues.italic ? "italic" : "not-italic",
@@ -1986,8 +1986,8 @@ gTMPprefObserver = {
       return attrib.length > 1 && attrib.indexOf("not-bold") == -1;
     };
     // changing bold attribute can change tab width and effect tabBar scroll status
-    // also when we turn off unloaded, unread and other style diffrent style can take
-    // control with a diffrent bold attribute
+    // also when we turn off unloaded, unread and other style different style can take
+    // control with a different bold attribute
     if (isBold(attribValue || "") != isBold(currentAttrib)) {
       TabmixTabbar.updateScrollStatus();
       TabmixTabbar.updateBeforeAndAfter();
@@ -2111,8 +2111,8 @@ gTMPprefObserver = {
       if (Tabmix.isVersion(290)) {
         let buttonPosition = Tabmix.getPlacement("new-tab-button");
         let tabsPosition = Tabmix.getPlacement("tabbrowser-tabs");
-        let boxPositoin = Tabmix.getPlacement("tabmixScrollBox");
-        let after = boxPositoin == tabsPosition + 1 ? boxPositoin : tabsPosition;
+        let boxPosition = Tabmix.getPlacement("tabmixScrollBox");
+        let after = boxPosition == tabsPosition + 1 ? boxPosition : tabsPosition;
         let changePosition = (aPosition === 0 && buttonPosition > tabsPosition) ||
                              (aPosition == 1 && buttonPosition < after) ||
                              (aPosition == 2 && buttonPosition != after + 1);
@@ -2176,7 +2176,7 @@ gTMPprefObserver = {
     *  temporary-right-side
     *                  - show the button on right side when there is no place
     *                    for the button aftertabs in multi-row mode
-    *  rigth-side      - show the button on right side
+    *  right-side      - show the button on right side
     *  left-side       - show the button on left side
     */
     let attrValue;
@@ -2471,7 +2471,7 @@ gTMPprefObserver = {
         let nsISupportsString = Ci.nsISupportsString;
         let str = Cc["@mozilla.org/supports-string;1"].createInstance(nsISupportsString);
         str.data = Services.prefs.getComplexValue(oldPref, nsISupportsString).data;
-        // only updtae new preference value if the old control preference is New Tab Page
+        // only update new preference value if the old control preference is New Tab Page
         let control = controlPref === undefined || Tabmix.prefs.prefHasUserValue(controlPref) &&
                       Tabmix.prefs.getIntPref(controlPref) == 4;
         if (str.data !== "" && control)
@@ -2547,7 +2547,7 @@ gTMPprefObserver = {
       Tabmix.prefs.clearUserPref("dblClickTabbar_changesize");
     }
     // 2014-12-25
-    // don't synce sessions.onStart.sessionpath
+    // don't sync sessions.onStart.sessionpath
     Services.prefs.clearUserPref("services.sync.prefs.sync.extensions.tabmix.sessions.onStart.sessionpath");
     // 2015-07-15
     if (Tabmix.prefs.prefHasUserValue("loadFolderAndReplace")) {
@@ -2732,7 +2732,7 @@ TabmixProgressListener = {
             tab.removeAttribute("tabmix_pending");
           Tabmix.setTabStyle(tab);
           // this code run after setTabTitleLoading, so we must set tab width on setTabTitleLoading
-          // at this stage only unhide the button if needed.
+          // at this stage only un-hide the button if needed.
           if (this.mTabBrowser.tabContainer.getAttribute("closebuttons") == "noclose") {
             let tabsCount = this.mTabBrowser.visibleTabs.length;
             if (tabsCount == 1)
diff --git a/chrome/content/tabmix.js b/chrome/content/tabmix.js
index 93cf93f..f320184 100644
--- a/chrome/content/tabmix.js
+++ b/chrome/content/tabmix.js
@@ -142,7 +142,7 @@ Tabmix.getAfterTabsButtonsWidth = function TMP_getAfterTabsButtonsWidth() {
     }
 
     // when privateTab extension installed add its new tab button width
     // for the use of adjustNewtabButtonvisibility set tabsNewtabButton to be
     // the right button
     let openNewPrivateTab = document.getElementById("privateTab-afterTabs-openNewPrivateTab");
     if (openNewPrivateTab) {
@@ -214,7 +214,7 @@ Tabmix.afterDelayedStartup = function() {
     this.assert(ex);
   }
 
-  // starting with Fireofox 17.0+ we calculate TMP_tabDNDObserver.paddingLeft
+  // starting with Firefox 17.0+ we calculate TMP_tabDNDObserver.paddingLeft
   // in gBrowser.tabContainer._positionPinnedTabs
   TMP_tabDNDObserver.paddingLeft = this.getStyle(gBrowser.tabContainer, "paddingLeft");
 
@@ -231,7 +231,7 @@ Tabmix.afterDelayedStartup = function() {
       }
     }];
     let msg = "Tab Mix is in debug mode!\n " +
-      "In case it's activated accidentally, click the button to disalbe it " +
+      "In case it's activated accidentally, click the button to disable it " +
       "or set 'extensions.tabmix.enableDebug' in about:config to false. " +
       "Once you disable 'Debug Mode' restart your browser.";
     const errorimage = "chrome://tabmixplus/skin/tmpsmall.png";
@@ -377,7 +377,7 @@ var TMP_eventListener = {
 
     // initialize our gURLBar.handleCommand function early before other extensions change
     // gURLBar.handleCommand or searchbar.handleSearchCommand by replacing the original function
-    // url-fixer also prevent the use of eval changes by using closure in the replcaed function
+    // url-fixer also prevent the use of eval changes by using closure in the replaced function
     Tabmix.navToolbox.initializeURLBar();
     Tabmix.navToolbox.initializeSearchbar();
   },
@@ -857,7 +857,7 @@ var TMP_eventListener = {
 
   // TGM extension use it
   onTabClose_updateTabBar: function TMP_EL_onTabClose_updateTabBar(aTab) {
-    // if the tab is not in the curent group we don't have to do anything here.
+    // if the tab is not in the current group we don't have to do anything here.
     if (typeof aTab._tPosInGroup == "number" && aTab._tPosInGroup == -1)
       return;
 
@@ -883,7 +883,7 @@ var TMP_eventListener = {
       tabBar.mTabstrip.ensureElementIsVisible(gBrowser.selectedTab, false);
 
     if (Tabmix.tabsUtils.disAllowNewtabbutton)
-      Tabmix.tabsUtils.adjustNewtabButtonvisibility();
+      Tabmix.tabsUtils.adjustNewtabButtonVisibility();
     if (TabmixTabbar.isMultiRow && tabBar.hasAttribute("multibar")) {
       _updateTabstrip();
       setTimeout(() => _updateTabstrip(), 0);
@@ -894,7 +894,7 @@ var TMP_eventListener = {
     var tab = aEvent.target;
 
     // for ColorfulTabs 6.0+
-    // ColorfulTabs trapp TabSelect event after we do
+    // ColorfulTabs traps TabSelect event after we do
     // we need to set standout class before we check for getTabRowNumber
     // and mTabstrip.ensureElementIsVisible
     // this class change tab height (by changing the borders)
@@ -973,8 +973,8 @@ var TMP_eventListener = {
       return;
     }
     let tabBar = gBrowser.tabContainer;
-    let tabsSrip = tabBar.mTabstrip;
-    let orient = tabsSrip.orient;
+    let tabStrip = tabBar.mTabstrip;
+    let orient = tabStrip.orient;
     TabmixTabbar.removeShowButtonAttr();
 
     let shouldMoveFocus = scrollTabs == 1;
@@ -988,13 +988,13 @@ var TMP_eventListener = {
       } else {
         isVertical = Math.abs(aEvent.deltaY) > Math.abs(aEvent.deltaX);
         let delta = isVertical ? aEvent.deltaY : aEvent.deltaX;
-        direction = isVertical && tabsSrip._isRTLScrollbox ? -delta : delta;
+        direction = isVertical && tabStrip._isRTLScrollbox ? -delta : delta;
       }
     } else {
       direction = aEvent.detail;
       if (orient != "vertical") {
         isVertical = aEvent.axis == aEvent.VERTICAL_AXIS;
-        direction = isVertical && tabsSrip._isRTLScrollbox ? -direction : direction;
+        direction = isVertical && tabStrip._isRTLScrollbox ? -direction : direction;
       }
     }
 
@@ -1012,13 +1012,13 @@ var TMP_eventListener = {
       let scrollByDelta = function(delta) {
         if (Tabmix.isVersion(480) &&
             aEvent.deltaMode == aEvent.DOM_DELTA_PIXEL) {
-          tabsSrip.scrollByPixels(delta);
+          tabStrip.scrollByPixels(delta);
         } else {
           // scroll the tabbar by one tab
           if (orient == "horizontal" || TabmixTabbar.isMultiRow) {
             delta = delta > 0 ? 1 : -1;
           }
-          tabsSrip.scrollByIndex(delta);
+          tabStrip.scrollByIndex(delta);
         }
       };
 
@@ -1028,13 +1028,13 @@ var TMP_eventListener = {
         }
         scrollByDelta(direction);
       } else {
-        if (tabsSrip._prevMouseScrolls.every(prev => prev == isVertical)) {
+        if (tabStrip._prevMouseScrolls.every(prev => prev == isVertical)) {
           scrollByDelta(direction);
         }
 
-        if (tabsSrip._prevMouseScrolls.length > 1)
-          tabsSrip._prevMouseScrolls.shift();
-        tabsSrip._prevMouseScrolls.push(isVertical);
+        if (tabStrip._prevMouseScrolls.length > 1)
+          tabStrip._prevMouseScrolls.shift();
+        tabStrip._prevMouseScrolls.push(isVertical);
       }
       aEvent.stopPropagation();
       aEvent.preventDefault();
@@ -1100,7 +1100,7 @@ var TMP_eventListener = {
     Tabmix.bottomToolbarUtils.onUnload();
   },
 
-  // some theme not useing up to date Tabmix tab binding
+  // some theme not using up to date Tabmix tab binding
   // we check here that all of our attribute exist
   setTabAttribute: function TMP_EL_setTabAttribute(aTab) {
     let reloadIcon = document.getAnonymousElementByAttribute(aTab, "class", "tab-reload-icon");
@@ -1141,7 +1141,7 @@ Tabmix.initialization = {
     /**
       * don't initialize Tabmix functions on this window if one of this is true:
       *  - the window is about to close by SingleWindowModeUtils
-      *  - tabbrowser-tabs binding didn't start (i onlly saw it happened
+      *  - tabbrowser-tabs binding didn't start (i only saw it happened
       *       when ImTranslator extension installed)
       */
     let stopInitialization = false;
@@ -142,7 +142,7 @@ Tabmix.getAfterTabsButtonsWidth = function TMP_getAfterTabsButtonsWidth() {
 
     // when privateTab extension installed add its new tab button width
-    // for the use of adjustNewtabButtonvisibility set tabsNewtabButton to be
+    // for the use of adjustNewtabButtonVisibility set tabsNewtabButton to be
     // the right button
     let openNewPrivateTab = document.getElementById("privateTab-afterTabs-openNewPrivateTab");
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/tabmixplus.git



More information about the Pkg-mozext-commits mailing list